from setuptools import setup, find_packages


classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name = 'secretListing',
    version = '0.0.1',
    description = 'Makes operations on lists easy.',
    long_description = open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url = '',
    author = 'Damian Czapla',
    author_email = 'damianczapla121212@gmail.com',
    License = 'MIT',
    classifiers = classifiers,
    keywords = 'secret',
    packages = find_packages(),
    install_requires = ['']

)